TeethCustomPaint class

Inheritance

Constructors

TeethCustomPaint({required List<TeethModel> models, required BuildContext context, required DrawableRoot drawableRoot, required void onTap(String id, bool isSelected), Color unSelectedColor = Colors.black, Color selectedColor = Colors.green, Color borderColor = Colors.black, double? textPaddingTop, double? textPaddingLeft, double borderWith = 1, TextStyle style = const TextStyle(color: Colors.black, fontSize: 10), bool showIndex = false})

Properties

borderColor Color
final
borderWith double
final
context BuildContext
getter/setter pair
drawableRoot ↔ DrawableRoot
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
models List<TeethModel>
getter/setter pair
onTap ↔ void Function(String id, bool isSelected)
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedColor Color
final
semanticsBuilder SemanticsBuilderCallback?
Returns a function that builds semantic information for the picture drawn by this painter.
no setterinherited
showIndex bool
final
style TextStyle
final
textPaddingLeft double?
final
textPaddingTop double?
final
unSelectedColor Color
final

Methods

addListener(VoidCallback listener) → void
Register a closure to be notified when it is time to repaint.
inherited
drawPaths({required TouchyCanvas touchyCanvas, required Canvas plainCanvas, required Size size, required bool showIndex, required Iterable<Drawable> drawables, required Matrix4 fittingMatrix, double? textPaddingLeft, double? textPaddingTop}) → void
hitTest(Offset position) bool?
Called whenever a hit test is being performed on an object that is using this custom paint delegate.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paint(Canvas canvas, Size size) → void
Called whenever the object needs to paint. The given Canvas has its coordinate space configured such that the origin is at the top left of the box. The area of the box is the size of the size argument.
override
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that the object notifies when it is time to repaint.
inherited
shouldRebuildSemantics(covariant CustomPainter oldDelegate) bool
Called whenever a new instance of the custom painter delegate class is provided to the RenderCustomPaint object, or any time that a new CustomPaint object is created with a new instance of the custom painter delegate class (which amounts to the same thing, because the latter is implemented in terms of the former).
inherited
shouldRepaint(covariant CustomPainter oldDelegate) bool
Called whenever a new instance of the custom painter delegate class is provided to the RenderCustomPaint object, or any time that a new CustomPaint object is created with a new instance of the custom painter delegate class (which amounts to the same thing, because the latter is implemented in terms of the former).
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited